## neptune_aws 1.1.1

### Changes
- Updated `pyproject.toml` ([#8](https://github.com/neptune-ai/neptune-aws/pull/8))

## neptune_aws 1.1.0

### Fixes
- Add missing boto3 dependency to the requirements ([#6](https://github.com/neptune-ai/neptune-aws/pull/6))

## neptune_aws 1.0.0

### Changes
- Removed `neptune` and `neptune-client` from base requirements  ([#5](https://github.com/neptune-ai/neptune-aws/pull/5))

## neptune_aws 0.0.0

### Breaking changes
- First ([#1](https://github.com/neptune-ai/neptune-aws/pull/1))

### Features
- First ([#1](https://github.com/neptune-ai/neptune-aws/pull/1))

### Fixes
- First ([#1](https://github.com/neptune-ai/neptune-aws/pull/1))
